@@ -1,12 +1,9 @@
-
-require 'runit/testcase'
+$:.unshift File.dirname(__FILE__)
 require 'tmail/address'
 require 'extctrl'
+require 'test/unit'
 
-
-class AddressTester < RUNIT::TestCase
-
-  testme!
+class AddressTester < Test::Unit::TestCase
 
   def test_s_new
     a = TMail::Address.new(%w(aamine), %w(loveruby net))
@@ -876,8 +873,8 @@ class AddressTester < RUNIT::TestCase
         :local        => '""',
         :format       => '""@example.com'
 
-    assert_exception( TMail::SyntaxError ) {
-        TMail::Address.parse '@example.com'
+    assert_raise(TMail::SyntaxError) {
+      TMail::Address.parse '@example.com'
     }
 
     validate_case__address\
@@ -916,11 +913,11 @@ class AddressTester < RUNIT::TestCase
 	  :format => 'sam' }] ]
 =end
 
-    assert_exception( TMail::SyntaxError ) {
-        TMail::Address.parse 'Undisclosed <>'
+    assert_raises(TMail::SyntaxError) {
+      TMail::Address.parse 'Undisclosed <>'
     }
-    assert_exception( TMail::SyntaxError ) {
-        TMail::Address.parse '"Mensagem Automatica do Terra" <>'
+    assert_raises(TMail::SyntaxError) {
+      TMail::Address.parse '"Mensagem Automatica do Terra" <>'
     }
 
     # These test cases are meanful in Japanese charset context.
